<template>
  <page-toggle-transition
    v-if="isShow"
    :disabled="animate.disabled"
    :animate="animate.name"
    :direction="animate.direction"
  >
    <div class="page-content">
      <advance-table
        :data-source="dataSource"
        :columns="columns"
        :loading="loading"
        row-key="id"
        :scroll="{ x: 2000, y }"
        @search="onSearch"
        @refresh="onRefresh"
        @reset="onReset"
        :format-conditions="true"
        :row-class-name="getRowClassName"
        :pagination="{
          current: page,
          pageSize: pageSize,
          total: total,
          showSizeChanger: true,
          showLessItems: true,
          showQuickJumper: true,
          showTotal: (total, range) =>
            `第 ${range[0]}-${range[1]} 条，总计 ${total} 条`,
          onChange: onPageChange,
          onShowSizeChange: onSizeChange,
        }"
      >
        <template slot="title">
          <div class="title">问题反馈</div>
          <a-radio-group
            v-model="flag"
            @change="flagChange"
            button-style="solid"
          >
            <a-radio-button :value="0">未处理</a-radio-button>
            <a-radio-button :value="1">已确认</a-radio-button>
            <a-radio-button :value="2">已完结</a-radio-button>
          </a-radio-group>
          <a-button
            class="ml-20"
            type="primary"
            icon="plus"
            @click="showFeedback"
            >反馈问题</a-button
          >
        </template>
        <template slot="action" slot-scope="{ record }">
          <!-- <a-popconfirm
            title="是否确认该问题"
            v-if="0 == record.confirmStatus && isReceiver"
            @confirm="confirmFk(record)"
          >
            <a href="#">确认</a>
          </a-popconfirm> -->
          <a href="#" @click="showDetails(record)">详情</a>
          <template v-if="canDispatch && '杨红兰' == record.receiverNames">
            <a-divider type="vertical"></a-divider>
            <a href="#" @click="dispatch(record)">指派</a>
          </template>
          <template v-if="0 == record.confirmStatus && isReceiver">
            <a-divider type="vertical"></a-divider>
            <a href="#" @click="showConfirm(record)">确认</a>
          </template>
          <template v-if="3 == record.confirmStatus && isReceiver">
            <a-divider type="vertical"></a-divider>
            <a href="#" @click="showFinish(record)">完结</a>
          </template>
        </template>
      </advance-table>
    </div>
    <a-modal
      :visible="feedBackVisible"
      :width="800"
      title="问题反馈"
      :destroyOnClose="true"
      :footer="false"
      @cancel="feedbackCancel"
    >
      <feedback-form @cancel="feedbackCancel" @ok="feedbackOk"></feedback-form>
    </a-modal>
    <a-modal
      :visible="detailsVisible"
      :width="800"
      title="问题反馈详情"
      :destroyOnClose="true"
      :maskClosable="false"
      :footer="false"
      @cancel="detailsCancel"
    >
      <feedback-details :fk-data="currFk"></feedback-details>
      <template v-if="isConfirm">
        <a-row class="row" :gutter="16">
          <a-col :span="6" class="label">处理类型</a-col>
          <a-col :span="18">
            <a-select
              v-model="confirmStatus"
              placeholder="请选择处理类型"
              @change="confirmStatusChange"
              style="width: 100%"
            >
              <a-select-option :disabled="user.name == '杨红兰'" :value="1"
                >与我无关</a-select-option
              >
              <a-select-option :value="2">不需要修改bom</a-select-option>
              <a-select-option :value="3">需要修改bom</a-select-option>
            </a-select>
          </a-col>
        </a-row>
        <a-row class="row" v-if="showReplyContent" :gutter="16">
          <a-col :span="6" class="label">回复内容</a-col>
          <a-col :span="18">
            <yc-textarea
              placeholder="请输入回复内容"
              v-model="replyContent"
              show-word-limit
              :maxLength="300"
              :rows="6"
            />
          </a-col>
        </a-row>
      </template>
      <div class="footer">
        <a-button class="btn" @click="detailsCancel">关闭</a-button>
        <a-button class="btn" v-if="isConfirm" @click="confirmFk" type="primary"
          >确认</a-button
        >
      </div>
    </a-modal>
    <!-- 指派 -->
    <a-modal
      :visible="dispatchVisible"
      :width="600"
      title="指派"
      :destroyOnClose="true"
      :maskClosable="false"
      @cancel="dispatchCancel"
      @ok="dispatchOk"
    >
      <feedback-details :fk-data="currFk"></feedback-details>
      <a-row class="row" :gutter="16">
        <a-col :span="6" class="label">指派给</a-col>
        <a-col :span="18">
          <a-select
            placeholder="请选择反馈接收人"
            show-search
            v-model="toUsers"
            style="width: 100%"
          >
            <a-select-option
              v-for="(user, idx) in userList"
              :key="'user_' + idx"
              :value="user.id + '&&' + user.name"
            >
              {{ user.name }}
            </a-select-option>
          </a-select>
        </a-col>
      </a-row>
    </a-modal>
    <!-- 完结 -->
    <a-modal
      :visible="finishVisible"
      :width="600"
      title="关联变更单号"
      :destroyOnClose="true"
      :maskClosable="false"
      @cancel="finishCancel"
      @ok="finishOk"
    >
      <feedback-details :fk-data="currFk"></feedback-details>
      <a-row class="row" :gutter="16">
        <a-col :span="6" class="label">变更单号</a-col>
        <a-col :span="18">
          <a-select
            placeholder="请选择变更单号"
            show-search
            v-model="ecrNumber"
            style="width: 100%"
          >
            <a-select-option
              v-for="(ecr, idx) in ecrList"
              :key="'ecr_' + idx"
              :value="ecr.number"
            >
              {{ ecr.number }}
            </a-select-option>
          </a-select>
        </a-col>
      </a-row>
    </a-modal>
  </page-toggle-transition>
</template>

<script>
import PageToggleTransition from "@/components/transition/PageToggleTransition";
import AdvanceTable from "@/components/table/advance/AdvanceTable";
import { mapGetters, mapState } from "vuex";
import {
  getSenderStatus,
  getRecevierStatus,
  confirmFk,
  submitFeedback,
  dispatch,
  updateEcrNumber,
} from "@/pages/workplace/apis";
import { getUserByRoleIds } from "@/pages/user/apis";
import { getAllList } from "@/pages/resourceManage/ecr/apis";
import DrawUpload from "@/pages/components/drawUpload/DrawUpload";
import AuditForm from "@/pages/workplace/workForm/auditForm";
import ReplaceInfo from "../replaceInfo";
import MaterialInfo from "../materialInfo";
import FeedbackForm from "@/pages/resourceManage/components/feedbackForm.vue";
import FeedbackDetails from "../../resourceManage/components/feedbackDetails.vue";
import YcTextarea from "@/components/input/ycTextarea";
const columns = [
  {
    title: "料号",
    dataIndex: "parentCode",
    align: "center",
    noSearch: true,
    width: 120,
  },
  {
    title: "产品名称",
    dataIndex: "parentName",
    align: "center",
    noSearch: true,
    width: 120,
  },
  {
    title: "产品型号",
    dataIndex: "parentModel",
    align: "center",
    noSearch: true,
    width: 300,
  },
  {
    title: "定制单号",
    dataIndex: "customCode",
    align: "center",
    noSearch: true,
    width: 120,
  },
  {
    title: "版本时间",
    dataIndex: "versionTime",
    align: "center",
    noSearch: true,
    width: 120,
  },
  {
    title: "创建人",
    dataIndex: "senderName",
    align: "center",
    noSearch: true,
  },
  {
    title: "创建时间",
    dataIndex: "createTime",
    align: "center",
    noSearch: true,
  },
  {
    title: "反馈接收人",
    dataIndex: "receiverNames",
    align: "center",
    noSearch: true,
  },
  {
    title: "确认人",
    dataIndex: "confirmUserName",
    align: "center",
    noSearch: true,
  },
  {
    title: "回复内容",
    dataIndex: "replyContent",
    align: "center",
    noSearch: true,
  },
  {
    title: "回复时间",
    dataIndex: "replyTime",
    align: "center",
    noSearch: true,
  },
  {
    title: "变更单流水号",
    dataIndex: "ecrNumber",
    align: "center",
    noSearch: true,
  },
  {
    title: "操作",
    dataIndex: "operation",
    key: "operation",
    align: "center",
    noSearch: true,
    fixed: "right",
    width: 160,
    scopedSlots: { customRender: "action" },
  },
];
export default {
  components: {
    DrawUpload,
    PageToggleTransition,
    AdvanceTable,
    AuditForm,
    ReplaceInfo,
    MaterialInfo,
    FeedbackForm,
    FeedbackDetails,
    YcTextarea,
  },
  props: {
    isShow: {
      type: Boolean,
      default: false,
    },
    y: {
      type: Number,
      default: 400,
    },
    type: {
      type: String,
    },
  },
  watch: {
    isShow(n) {
      if (n) {
        this.searchData();
      }
    },
  },
  data() {
    return {
      ecrList: [],
      ecrNumber: "",
      finishVisible: false,
      toUsers: "",
      userList: [],
      dispatchId: "",
      showReplyContent: false,
      replyContent: "",
      confirmStatus: undefined,
      isConfirm: false,
      currFk: null,
      dispatchVisible: false,
      detailsVisible: false,
      feedBackVisible: false,
      flag: 0,
      loading: false,
      workDetailVisible: false,
      auditFormVisible: false,
      page: 1,
      pageSize: 10,
      total: 0,
      conditions: {},
      dataSource: [],
      title: "",
      subList: [],
      columns: columns.map((v) => v),
      formData: {
        id: 0, // 连接id
        mainId: 0, // 主id
        linkStatus: 1, // 审批状态 1:通过，2：驳回
        dealReason: "", // 审核建议
        nextUser: 0, // 下一个审核的用户id
      },
    };
  },
  methods: {
    onSearch(conditions, searchOptions) {
      this.page = 1;
      this.conditions = conditions;
      this.searchData();
    },
    onPageChange(page, pageSize) {
      this.page = page;
      this.pageSize = pageSize;
      this.searchData();
    },
    onSizeChange(current, size) {
      this.page = 1;
      this.pageSize = size;
      this.searchData();
    },
    onRefresh(conditions) {
      this.conditions = conditions;
      this.searchData();
    },
    onReset(conditions) {
      this.conditions = conditions;
      this.searchData();
    },
    searchData() {
      let getList = this.isReceiver ? getRecevierStatus : getSenderStatus;
      let flags = [];
      switch (this.flag) {
        case 0:
          flags = [0];
          break;
        case 1:
          flags = [3];
          break;
        case 2:
          flags = [2, 4];
          break;
      }
      getList(flags.join(","), this.page, this.pageSize).then((res) => {
        let { code, data, data2 } = res.data;
        let total = 0,
          list = [];
        if (code && data) {
          total = data2.total;
          list = data2.list;
        }
        this.total = total;
        this.dataSource = list;
        this.$emit("resize");
      });
    },
    showFeedback() {
      this.feedBackVisible = true;
    },
    feedbackCancel() {
      this.feedBackVisible = false;
    },
    feedbackOk(data) {
      // console.log(data, ";xxxs");
      let {
        content,
        multipartFile,
        productId,
        receiverIds,
        receiverNames,
        senderId,
        subVersion,
      } = data;
      let loading = this.$layer.loading({ shade: true });
      const formData = new FormData();
      multipartFile.forEach((v) => {
        formData.append("multipartFileList", v);
      });
      formData.append(
        "feedbackJson",
        JSON.stringify({
          content,
          productId,
          receiverIds,
          receiverNames,
          senderId,
          subVersion,
        })
      );
      submitFeedback(formData).then((res) => {
        let { code, data } = res.data;
        if (code && data) {
          this.$message.success("反馈成功");
          this.feedBackVisible = false;
          this.$layer.close(loading);
          this.flag = 0;
          this.page = 1;
          this.searchData();
        } else {
          this.$layer.close(loading);
          this.$message.error("反馈失败");
        }
      });
    },
    flagChange() {
      this.page = 1;
      this.searchData();
    },
    confirmFk() {
      let id = this.currFk.id;
      let { confirmStatus, replyContent } = this;
      let loading = this.$layer.loading();
      confirmFk(id, confirmStatus, replyContent).then((res) => {
        let { code, data, msg } = res.data;
        if (code && data) {
          this.$message.success("确认成功");
          this.detailsVisible = false;
          this.$layer.close(loading);
          this.flagChange();
        } else {
          this.$message.warning(msg);
          this.$layer.close(loading);
        }
      });
    },
    showDetails(obj) {
      this.currFk = obj;
      this.isConfirm = false;
      this.detailsVisible = true;
    },
    showConfirm(obj) {
      this.currFk = obj;
      this.isConfirm = true;
      this.detailsVisible = true;
    },
    showFinish(obj) {
      this.currFk = obj;
      this.ecrNumber = "";
      this.finishVisible = true;
    },
    detailsCancel() {
      this.detailsVisible = false;
      this.initForm();
    },
    detailsOk() {
      this.detailsVisible = false;
    },
    initForm() {
      this.replyContent = "";
      this.confirmStatus = undefined;
      this.showReplyContent = false;
    },
    confirmStatusChange(v) {
      if (2 == v || 3 == v) {
        this.showReplyContent = true;
      } else {
        this.showReplyContent = false;
      }
    },
    getRowClassName(record) {
      if (this.canDispatch && "杨红兰" == record.receiverNames) {
        return "warning";
      }
      return "";
    },
    dispatch(record) {
      this.currFk = record;
      this.dispatchId = record.id;
      this.dispatchVisible = true;
    },
    dispatchCancel() {
      this.dispatchVisible = false;
    },
    dispatchOk() {
      let { toUsers, dispatchId } = this;
      if (!toUsers) {
        this.$message.error("请选择要指派的用户");
        return false;
      }
      let [id, name] = toUsers.split("&&");
      let loading = this.$layer.loading();
      dispatch(dispatchId, id, name).then((res) => {
        let { code } = res.data;
        if (code) {
          this.$message.success("操作成功");
          this.$layer.close(loading);
          this.dispatchVisible = false;
          this.searchData();
        } else {
          this.$message.error("操作失败");
          this.$layer.close(loading);
        }
      });
    },
    // 获取多个角色组的所有用户
    getUserByRoleIds() {
      getUserByRoleIds("1001,1002,1003")
        .then((res) => {
          let { code, data, data2 } = res.data;
          let list = [];
          if (code && data) {
            // console.log(data2);
            list = data2.filter((v) => v.name != this.user.name);
          }
          // console.log(list, "====list");
          this.userList = list;
        })
        .catch((err) => {
          console.error(err);
        });
    },
    getEcrList() {
      getAllList().then((res) => {
        let { code, data, data2 } = res.data;
        let list = [];
        if (code && data) {
          list = data2;
        }
        this.ecrList = list;
      });
    },
    finishCancel() {
      this.finishVisible = false;
    },
    finishOk() {
      let { ecrNumber, currFk } = this;
      if (!ecrNumber) {
        this.$message.error("请选择变更单号");
        return false;
      }
      let loading = this.$layer.loading();
      updateEcrNumber(currFk.id, ecrNumber).then((res) => {
        let { code, data } = res.data;
        if (code && data) {
          this.$layer.close(loading);
          this.$message.success("操作成功");
          this.finishVisible = false;
          this.searchData();
        } else {
          this.$layer.close(loading);
          this.$message.error("操作失败");
        }
      });
    },
  },
  computed: {
    ...mapState("setting", ["animate"]),
    ...mapGetters("account", ["user"]),
    workDetailTitle() {
      return this.title;
    },
    canDispatch() {
      return 0 == this.flag && "杨红兰" == this.user.name;
    },
    isReceiver() {
      return this.type == "recevierFk";
    },
  },
  mounted() {
    this.searchData();
    this.getUserByRoleIds();
    this.getEcrList();
  },
};
</script>

<style lang="less" scoped>
.title {
  display: inline-block;
  margin-right: 20px;
}

.ml-20 {
  margin-left: 20px;
}

.footer {
  text-align: right;

  .btn + .btn {
    margin-left: 20px;
  }
}

.row {
  margin-bottom: 12px;
}

.label {
  // display: flex;
  // justify-content: flex-end;
  // align-items: center;
  color: rgba(0, 0, 0, 0.85);
  // padding-right: 0.4em;
  height: 32px;
  line-height: 32px;
  text-align: right;

  &::after {
    content: ":";
    margin-left: 2px;
    margin-right: 8px;
  }
}

/deep/.warning > td {
  background: #f7dea7;
}

// /deep/.warning.warning.ant-table-row-hover > td,
// /deep/.warning.warning:hover > td {
//   background: #f8c34f;
// }
</style>